## Badges
[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)
![PyPI - Version](https://img.shields.io/pypi/v/openredirect)



<p align="center">

## License
[MIT](https://choosealicense.com/licenses/mit/)

## Installation 

1. Install Python3 and pip [Instructions Here](https://www.python.org/downloads/) (If you can't figure this out, you shouldn't really be using this)

   - Install via pip
     - ```bash
          pip install openredirect
        ```
   - Run bellow command to check
     - `openredirect-check -h`


## Usages 
2. This tool has multiple use cases.
   
   - To Check Single URL
     - ```bash
          openredirect-check -u http://example.com/?url= 
        ```
   - To Check List of URL 
      - ```bash
          openredirect-check -l urls.txt 
        ```
   - Save output into TXT file
      - ```bash
          openredirect-check -l urls.txt -o output_name_file.txt
        ```


## Help menu

#### Get all items

```bash
👋 Hey Hacker
                                                            v1.0


 ▄██████▄     ▄███████▄    ▄████████ ███▄▄▄▄      ▄████████    ▄████████ ████████▄   ▄█     ▄████████    ▄████████  ▄████████     ███        ▄████████    ▄████████ 
███    ███   ███    ███   ███    ███ ███▀▀▀██▄   ███    ███   ███    ███ ███   ▀███ ███    ███    ███   ███    ███ ███    ███ ▀█████████▄   ███    ███   ███    ███ 
███    ███   ███    ███   ███    █▀  ███   ███   ███    ███   ███    █▀  ███    ███ ███▌   ███    ███   ███    █▀  ███    █▀     ▀███▀▀██   ███    █▀    ███    ███ 
███    ███   ███    ███  ▄███▄▄▄     ███   ███  ▄███▄▄▄▄██▀  ▄███▄▄▄     ███    ███ ███▌  ▄███▄▄▄▄██▀  ▄███▄▄▄     ███            ███   ▀  ▄███▄▄▄      ▄███▄▄▄▄██▀ 
███    ███ ▀█████████▀  ▀▀███▀▀▀     ███   ███ ▀▀███▀▀▀▀▀   ▀▀███▀▀▀     ███    ███ ███▌ ▀▀███▀▀▀▀▀   ▀▀███▀▀▀     ███            ███     ▀▀███▀▀▀     ▀▀███▀▀▀▀▀   
███    ███   ███          ███    █▄  ███   ███ ▀███████████   ███    █▄  ███    ███ ███  ▀███████████   ███    █▄  ███    █▄      ███       ███    █▄  ▀███████████ 
███    ███   ███          ███    ███ ███   ███   ███    ███   ███    ███ ███   ▄███ ███    ███    ███   ███    ███ ███    ███     ███       ███    ███   ███    ███ 
 ▀██████▀   ▄████▀        ██████████  ▀█   █▀    ███    ███   ██████████ ████████▀  █▀     ███    ███   ██████████ ████████▀     ▄████▀     ██████████   ███    ███ 
                                                 ███    ███                                ███    ███                                                    ███    ███ 


                                    Developed By https://tenet.com

openredirect : Bug scanner for WebPentesters and Bugbounty Hunters 

$ openredirectcheck [option]

Usage: openredirectcheck [options]
```


| Argument | Type     | Description                | Examples |
| :-------- | :------- | :------------------------- | :------------------------- |
| `-u` | `--url` | URL to scan | openredirectcheck -u https://target.com |
| `-i` | `--input` | filename Read input from txt  | openredirectcheck -i target.txt | 
| `-o` | `--output` | filename Write output in txt file | openredirectcheck -i target.txt -o output.txt | |
| `-b` | `--blog` | To Read about openredirect Bug | openredirectcheck -b |
| `-h` | `--help` | Help Menu | openredirectcheck -h |



## 🔗 Links
[![Website](https://img.shields.io/badge/my_portfolio-000?style=for-the-badge&logo=ko-fi&logoColor=white)](https://narenp-cybersecurity-281608w.gamma.site/)
[![linkedin](https://img.shields.io/badge/linkedin-0A66C2?style=for-the-badge&logo=linkedin&logoColor=white)](www.linkedin.com/in/naren-p-3407b3228)




## Author

- [@TENET_B2H](https://github.com/NAREN-P)
